.. _spkg_webcolors:

webcolors: Library for working with the color formats defined by HTML and CSS
=======================================================================================

Description
-----------

Library for working with the color formats defined by HTML and CSS

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/webcolors/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    1.13

version_requirements.txt::

    webcolors


Equivalent System Packages
--------------------------

(none known)

